N.C. Appellate Courts
Keywords: supreme, court

SUPREME COURT OPINIONS - 1998
Last Modified: December 21 2013 09:21:11 AM

31 December 1998 Zip File of Published Opinions Mandate: 20 January 1999 Case Title / Description
State v. McNeill, 349 NC 634 (184A96) - Opinion not available
State v. Murillo, 349 NC 573 (209A96) - Opinion not available
State v. Call, 349 NC 382 (341A96) - Opinion not available
State v. White, 349 NC 535 (505A96) - Opinion not available
State v. Bowman, 349 NC 459 (142A97) - Opinion not available
State v. Trull, 349 NC 428 (205A97) - Opinion not available
State v. Mathis, 349 NC 503 (10PA98) - Opinion not available
State v. Thompson, 349 NC 483 (80PA98) - Opinion not available
Brown v. Flowe, 349 NC 520 (110PA98) - Opinion not available
Meads v. N.C. Dep't of Agric., 349 NC 656 (139A98) - Opinion not available
Adams v. AVX Corp., 349 NC 676 (151PA98) - Opinion not available
Nelson v. Freeland, 349 NC 615 (216A98) - Opinion not available
IN ADDITION TO THE ABOVE LISTED OPINIONS, THE COURT CONSIDERED OTHER MATTERS. THE OTHER MATTERS MAY INCLUDE, BUT ARE NOT LIMITED TO, NOTICES OF APPEALS BASED UPON CONSTITUTIONAL QUESTIONS, PETITIONS FOR DISCRETIONARY REVIEW, PETITIONS FOR WRIT OF CERTIORARI IN DEATH CASES, DEATH STAYS, PETITIONS FOR WRITS OF CERTIORARI IN OTHER CRIMINAL AND CIVIL CASES, PETITIONS FOR WRITS OF SUPERSEDEAS, MOTIONS FOR TEMPORARY STAYS, PETITIONS FOR WRITS OF MANDAMUS, PETITIONS FOR WRITS OF HABEAS CORPUS, PETITIONS FOR WRIT OF MANDAMUS, MOTIONS FOR APPROPRIATE RELIEF, AND DIRECT APPEALS FROM DECISIONS OF THE JUDICIAL STANDARDS COMMISSION AND THE UTILITIES COMMISSION. THE COURT ALSO CONSIDERS MOTIONS FOR EXTENSIONS OF TIME AND MOTIONS TO AMEND ON A DAILY BASIS. SUCH "ROUTINE" MOTIONS ARE NOT INCLUDED IN THE PETITION LIST PUBLISHED BY THE COURT EACH MONTH.
4 December 1998 Zip File of Published Opinions Mandate: 28 December 1998 Case Title / Description
Peace v. Employment Security Commission #+#, 349 NC 315 (599A97)
Ryan v. UNC Hospitals, 349 NC 349 (48PA98)
News & Observer Publishing Co., Inc. v. Coble, 349 NC 350 (53PA98)
Smith v. State of North Carolina, 349 NC 332 (61A98)
Polaroid Corp. v. Offerman, 349 NC 290 (70PA98)
State v. Swindler, 349 NC 347 (161A98)
Ball v. Randolph Co. Bd. Adjust., 349 NC 348 (172PA98)
Bethune v. County of Harnett, 349 NC 343 (174PA98)
IN ADDITION TO THE ABOVE LISTED OPINIONS, THE COURT CONSIDERED OTHER MATTERS. THE OTHER MATTERS MAY INCLUDE, BUT ARE NOT LIMITED TO, NOTICES OF APPEALS BASED UPON CONSTITUTIONAL QUESTIONS, PETITIONS FOR DISCRETIONARY REVIEW, PETITIONS FOR WRIT OF CERTIORARI IN DEATH CASES, DEATH STAYS, PETITIONS FOR WRITS OF CERTIORARI IN OTHER CRIMINAL AND CIVIL CASES, PETITIONS FOR WRITS OF SUPERSEDEAS, MOTIONS FOR TEMPORARY STAYS, PETITIONS FOR WRITS OF MANDAMUS, PETITIONS FOR WRITS OF HABEAS CORPUS, PETITIONS FOR WRIT OF MANDAMUS, MOTIONS FOR APPROPRIATE RELIEF, AND DIRECT APPEALS FROM DECISIONS OF THE JUDICIAL STANDARDS COMMISSION AND THE UTILITIES COMMISSION. THE COURT ALSO CONSIDERS MOTIONS FOR EXTENSIONS OF TIME AND MOTIONS TO AMEND ON A DAILY BASIS. SUCH "ROUTINE" MOTIONS ARE NOT INCLUDED IN THE PETITION LIST PUBLISHED BY THE COURT EACH MONTH.
6 November 1998 Zip File of Published Opinions Mandate: 30 November 1998 Case Title / Description
State v. Guevara, 349 NC 243 (296A96)
State v. LaPlanche, 349 NC 279 (582A97)
State v. Flippen, 349 NC 264 (178A95-2) - Opinion not available
State v. Ballard, 349 NC 286 (488A97)
County of Carteret v. Long, 349 NC 285 (87A98)
State v. Wilson, 349 NC 289 (97PA98)
State v. Jackson, 349 NC 287 (126PA98)
Morgan v. State Farm Mutual Auto. Ins., 349 NC 288 (175A98)
IN ADDITION TO THE ABOVE LISTED OPINIONS, THE COURT CONSIDERED OTHER MATTERS. THE OTHER MATTERS MAY INCLUDE, BUT ARE NOT LIMITED TO, NOTICES OF APPEALS BASED UPON CONSTITUTIONAL QUESTIONS, PETITIONS FOR DISCRETIONARY REVIEW, PETITIONS FOR WRIT OF CERTIORARI IN DEATH CASES, DEATH STAYS, PETITIONS FOR WRITS OF CERTIORARI IN OTHER CRIMINAL AND CIVIL CASES, PETITIONS FOR WRITS OF SUPERSEDEAS, MOTIONS FOR TEMPORARY STAYS, PETITIONS FOR WRITS OF MANDAMUS, PETITIONS FOR WRITS OF HABEAS CORPUS, PETITIONS FOR WRIT OF MANDAMUS, MOTIONS FOR APPROPRIATE RELIEF, AND DIRECT APPEALS FROM DECISIONS OF THE JUDICIAL STANDARDS COMMISSION AND THE UTILITIES COMMISSION. THE COURT ALSO CONSIDERS MOTIONS FOR EXTENSIONS OF TIME AND MOTIONS TO AMEND ON A DAILY BASIS. SUCH "ROUTINE" MOTIONS ARE NOT INCLUDED IN THE PETITION LIST PUBLISHED BY THE COURT EACH MONTH.
9 October 1998 Zip File of Published Opinions Mandate: 29 October 1998 Case Title / Description
State v. Atkins, 349 NC 62 (9A94)
State v. Locklear, 349 NC 118 (235A96)
State v. Davis, 349 NC 1 (452A96)
State v. Hoffman, 349 NC 167 (313A97)
Davis v. N.C. Dept. of Human Resources, 349 NC 208 (314A97)
Estate of Mullis v. Monroe Oil Co., 349 NC 196 (426PA97)
Spears v. Centura Bank, 349 NC 223 (541PA97)
State v. Ruff, 349 NC 213 (550PA97)
Shackelford v. City of Wilmington, 349 NC 222 (561PA97)
Marshall v. Sizemore, 349 NC 221 (570A97)
Deason v. J. King Harrison Co., 349 NC 220 (591A97)
Williams v. Holsclaw, 349 NC 225 (28PA98)
Howard v. Square-D Company, 349 NC 224 (46PA98)
State v. Taylor, 349 NC 219 (71PA98)
Harrington v. Adams-Robinson Enterprises, 349 NC 218 (75A98)
State v. Hoover, 349 NC 226 (128PA98)
IN ADDITION TO THE ABOVE LISTED OPINIONS, THE COURT CONSIDERED OTHER MATTERS. THE OTHER MATTERS MAY INCLUDE, BUT ARE NOT LIMITED TO, NOTICES OF APPEALS BASED UPON CONSTITUTIONAL QUESTIONS, PETITIONS FOR DISCRETIONARY REVIEW, PETITIONS FOR WRIT OF CERTIORARI IN DEATH CASES, DEATH STAYS, PETITIONS FOR WRITS OF CERTIORARI IN OTHER CRIMINAL AND CIVIL CASES, PETITIONS FOR WRITS OF SUPERSEDEAS, MOTIONS FOR TEMPORARY STAYS, PETITIONS FOR WRITS OF MANDAMUS, PETITIONS FOR WRITS OF HABEAS CORPUS, PETITIONS FOR WRIT OF MANDAMUS, MOTIONS FOR APPROPRIATE RELIEF, AND DIRECT APPEALS FROM DECISIONS OF THE JUDICIAL STANDARDS COMMISSION AND THE UTILITIES COMMISSION. THE COURT ALSO CONSIDERS MOTIONS FOR EXTENSIONS OF TIME AND MOTIONS TO AMEND ON A DAILY BASIS. SUCH "ROUTINE" MOTIONS ARE NOT INCLUDED IN THE PETITION LIST PUBLISHED BY THE COURT EACH MONTH.
30 July 1998 Zip File of Published Opinions Mandate: 19 August 1998 Case Title / Description
Pulliam v. Smith, 348 NC 616 (499PA96)
State v. Green, 348 NC 588 (519A96)
State v. Jackson, 348 NC 644 (244PA97)
Bring v. N.C. State Bar, 348 NC 655 (355PA97)
Bethania Town Lot Committee v. City of Winston-Salem, 348 NC 664 (402PA97)
State v. Wall, 348 NC 671 (417PA97)
IN ADDITION TO THE ABOVE LISTED OPINIONS, THE COURT CONSIDERED OTHER MATTERS. THE OTHER MATTERS MAY INCLUDE, BUT ARE NOT LIMITED TO, NOTICES OF APPEALS BASED UPON CONSTITUTIONAL QUESTIONS, PETITIONS FOR DISCRETIONARY REVIEW, PETITIONS FOR WRIT OF CERTIORARI IN DEATH CASES, DEATH STAYS, PETITIONS FOR WRITS OF CERTIORARI IN OTHER CRIMINAL AND CIVIL CASES, PETITIONS FOR WRITS OF SUPERSEDEAS, MOTIONS FOR TEMPORARY STAYS, PETITIONS FOR WRITS OF MANDAMUS, PETITIONS FOR WRITS OF HABEAS CORPUS, PETITIONS FOR WRIT OF MANDAMUS, MOTIONS FOR APPROPRIATE RELIEF, AND DIRECT APPEALS FROM DECISIONS OF THE JUDICIAL STANDARDS COMMISSION AND THE UTILITIES COMMISSION. THE COURT ALSO CONSIDERS MOTIONS FOR EXTENSIONS OF TIME AND MOTIONS TO AMEND ON A DAILY BASIS. SUCH "ROUTINE" MOTIONS ARE NOT INCLUDED IN THE PETITION LIST PUBLISHED BY THE COURT EACH MONTH.
9 July 1998 Zip File of Published Opinions Mandate: 29 July 1998 Case Title / Description
State v. Lemons, 348 NC 335 (377A95)
State v. Fletcher, 348 NC 292 (117A96)
State v. Hipps, 348 NC 377 (272A96)
State v. Bonnett, 348 NC 417 (471A96)
State ex rel. Utilities Comm. v. Carolina Utility Customers Assn., 348 NC 452 (22A96)
State v. Lee, 348 NC 474 (544PA96)
Martin v. Benson, 348 NC 684 (119A97)
Farmah v. Farmah, 348 NC 586 (280PA97)
Robinson v. Powell, 348 NC 562 (334PA97)
DKH Corp. v. Rankin-Patterson Oil Co., 348 NC 583 (353PA97)
State v. Gary, 348 NC 510 (375PA97)
Sherrod v. Nash General Hospital, 348 NC 526 (387A97)
Martin Marietta Technologies v. Brunswick County, 348 NC 688 (421PA97)
State v. Helms, 348 NC 578 (468PA97)
State v. Fly, 348 NC 556 (472A97)
Briley v. Farabow, 348 NC 537 (473PA97)
Briggs v. Rankin, 348 NC 686 (536PA97)
Britt v. N.C. Sheriffs' Educ. and Training Standards Comm'n #+##+#, 348 NC 573 (600PA97)
Harlow v. Voyager Communications V, Inc.#+#, 348 NC 568 (612PA97)
In re Tucker, 348 NC 677 (617A97)
Kennedy v. Hawley, 348 NC 689 (20PA98)
Banks v. County of Buncombe#+##+#, 348 NC 687 (39A98)
IN ADDITION TO THE ABOVE LISTED OPINIONS, THE COURT CONSIDERED OTHER MATTERS. THE OTHER MATTERS MAY INCLUDE, BUT ARE NOT LIMITED TO, NOTICES OF APPEALS BASED UPON CONSTITUTIONAL QUESTIONS, PETITIONS FOR DISCRETIONARY REVIEW, PETITIONS FOR WRIT OF CERTIORARI IN DEATH CASES, DEATH STAYS, PETITIONS FOR WRITS OF CERTIORARI IN OTHER CRIMINAL AND CIVIL CASES, PETITIONS FOR WRITS OF SUPERSEDEAS, MOTIONS FOR TEMPORARY STAYS, PETITIONS FOR WRITS OF MANDAMUS, PETITIONS FOR WRITS OF HABEAS CORPUS, PETITIONS FOR WRIT OF MANDAMUS, MOTIONS FOR APPROPRIATE RELIEF, AND DIRECT APPEALS FROM DECISIONS OF THE JUDICIAL STANDARDS COMMISSION AND THE UTILITIES COMMISSION. THE COURT ALSO CONSIDERS MOTIONS FOR EXTENSIONS OF TIME AND MOTIONS TO AMEND ON A DAILY BASIS. SUCH "ROUTINE" MOTIONS ARE NOT INCLUDED IN THE PETITION LIST PUBLISHED BY THE COURT EACH MONTH.
8 May 1998 Zip File of Published Opinions Mandate: 28 May 1998 Case Title / Description
State v. Zuniga, 348 NC 214 (156A85-3)
State v. Warren, 348 NC 80 (116A96)
State v. Billings, 348 NC 169 (216A96)
State v. McHone, 348 NC 254 (148A91-2)
State v. Gregory, 348 NC 203 (19A97)
Bailey v. State of North Carolina, 348 NC 130 (53PA96)
City of Charlotte v. Cook, 348 NC 222 (83PA97)
Hunt v. N.C. Dept. of Labor, 348 NC 192 (110PA97)
Poole v. Copland, Inc., 348 NC 260 (145PA97)
State v. Pearson, 348 NC 272 (165PA97)
Liberty Mutual Ins. Co. v. Ditillo, 348 NC 247 (220A97)
Griffin v. Griffin, 348 NC 278 (276PA97)
State v. Rorie, 348 NC 266 (330PA97)
Elliott v. N.C. Psychology Bd., 348 NC 230 (340PA97)
Pearson v. P. C. Buckner Steel Erection Co., 348 NC 239 (452PA97)
IN ADDITION TO THE ABOVE LISTED OPINIONS, THE COURT CONSIDERED OTHER MATTERS. THE OTHER MATTERS MAY INCLUDE, BUT ARE NOT LIMITED TO, NOTICES OF APPEALS BASED UPON CONSTITUTIONAL QUESTIONS, PETITIONS FOR DISCRETIONARY REVIEW, PETITIONS FOR WRIT OF CERTIORARI IN DEATH CASES, DEATH STAYS, PETITIONS FOR WRITS OF CERTIORARI IN OTHER CRIMINAL AND CIVIL CASES, PETITIONS FOR WRITS OF SUPERSEDEAS, MOTIONS FOR TEMPORARY STAYS, PETITIONS FOR WRITS OF MANDAMUS, PETITIONS FOR WRITS OF HABEAS CORPUS, PETITIONS FOR WRIT OF MANDAMUS, MOTIONS FOR APPROPRIATE RELIEF, AND DIRECT APPEALS FROM DECISIONS OF THE JUDICIAL STANDARDS COMMISSION AND THE UTILITIES COMMISSION. THE COURT ALSO CONSIDERS MOTIONS FOR EXTENSIONS OF TIME AND MOTIONS TO AMEND ON A DAILY BASIS. SUCH "ROUTINE" MOTIONS ARE NOT INCLUDED IN THE PETITION LIST PUBLISHED BY THE COURT EACH MONTH.
3 April 1998 Zip File of Published Opinions Mandate: 23 April 1998 Case Title / Description
State v. Jackson, 348 NC 52 (12A96)
State v. Goode, 348 NC 69 (10A94-2)
State v. Bates, 348 NC 29 (145A91-3)
In re Springmoor, Inc., 348 NC 1 (79PA97)
Van Every v. McGuire, 348 NC 58 (159PA97)
Whitfield v. Gilchrist, 348 NC 39 (287PA97)
In re Will of Lamparter, 348 NC 45 (354A97)
Cissell v. Glover Landscape Supply, Inc., 348 NC 67 (356A97)
Walker v. Bd. of Trustees of N.C. Local Gov't Employees Ret. Sys.#+#, 348 NC 63 (482PA97)
Swann v. Len-Care Rest Home, Inc., 348 NC 68 (522A97)
IN ADDITION TO THE ABOVE LISTED OPINIONS, THE COURT CONSIDERED OTHER MATTERS. THE OTHER MATTERS MAY INCLUDE, BUT ARE NOT LIMITED TO, NOTICES OF APPEALS BASED UPON CONSTITUTIONAL QUESTIONS, PETITIONS FOR DISCRETIONARY REVIEW, PETITIONS FOR WRIT OF CERTIORARI IN DEATH CASES, DEATH STAYS, PETITIONS FOR WRITS OF CERTIORARI IN OTHER CRIMINAL AND CIVIL CASES, PETITIONS FOR WRITS OF SUPERSEDEAS, MOTIONS FOR TEMPORARY STAYS, PETITIONS FOR WRITS OF MANDAMUS, PETITIONS FOR WRITS OF HABEAS CORPUS, PETITIONS FOR WRIT OF MANDAMUS, MOTIONS FOR APPROPRIATE RELIEF, AND DIRECT APPEALS FROM DECISIONS OF THE JUDICIAL STANDARDS COMMISSION AND THE UTILITIES COMMISSION. THE COURT ALSO CONSIDERS MOTIONS FOR EXTENSIONS OF TIME AND MOTIONS TO AMEND ON A DAILY BASIS. SUCH "ROUTINE" MOTIONS ARE NOT INCLUDED IN THE PETITION LIST PUBLISHED BY THE COURT EACH MONTH.
6 March 1998 Zip File of Published Opinions Mandate: 26 March 1998 Case Title / Description
State v. Sanders, 347 NC 587 (88A85-3)
N.C. Steel v. National Council on Compensation Ins.#+##+#, 347 NC 627 (317PA96)
Powell v. N.C. Dept. of Transportation, 347 NC 614 (552PA96)
N.C.Dept. of Transportation v. Hodge, 347 NC 602 (559PA96)
Dept. of Transportation v. Humphries, 347 NC 649 (232PA97)
McAllister v. Sem Ha, 347 NC 638 (298PA97)
Cain v. Gencor, Inc., 347 NC 657 (318PA97)
Crisp v. Crisp, 347 NC 659 (323A97)
Richardson v. McCracken Enterprises, 347 NC 660 (341A97)
State v. Inman, 347 NC 661 (391A97)
Brady v. N.C. State Bd. of Dental Examiners, 347 NC 662 (398A97)
N.C. Dept. of Admin. v. Shaw Food Services, Inc., 347 NC 663 (411PA97)
Robbins v. Freeman, 347 NC 664 (416PA97)
Regan v. Amerimark Building Products, Inc., 347 NC 665 (449A97)
Page v. Marshall Oil Co., 347 NC 668 (455A97)
Kelly v. Food Lion, Inc., 347 NC 667 (469A97)
Nourse v. Food Lion, Inc., 347 NC 666 (471A97)
IN ADDITION TO THE ABOVE LISTED OPINIONS, THE COURT CONSIDERED OTHER MATTERS. THE OTHER MATTERS MAY INCLUDE, BUT ARE NOT LIMITED TO, NOTICES OF APPEALS BASED UPON CONSTITUTIONAL QUESTIONS, PETITIONS FOR DISCRETIONARY REVIEW, PETITIONS FOR WRIT OF CERTIORARI IN DEATH CASES, DEATH STAYS, PETITIONS FOR WRITS OF CERTIORARI IN OTHER CRIMINAL AND CIVIL CASES, PETITIONS FOR WRITS OF SUPERSEDEAS, MOTIONS FOR TEMPORARY STAYS, PETITIONS FOR WRITS OF MANDAMUS, PETITIONS FOR WRITS OF HABEAS CORPUS, PETITIONS FOR WRIT OF MANDAMUS, MOTIONS FOR APPROPRIATE RELIEF, AND DIRECT APPEALS FROM DECISIONS OF THE JUDICIAL STANDARDS COMMISSION AND THE UTILITIES COMMISSION. THE COURT ALSO CONSIDERS MOTIONS FOR EXTENSIONS OF TIME AND MOTIONS TO AMEND ON A DAILY BASIS. SUCH "ROUTINE" MOTIONS ARE NOT INCLUDED IN THE PETITION LIST PUBLISHED BY THE COURT EACH MONTH.
6 February 1998 Zip File of Published Opinions Mandate: 26 February 1998 Case Title / Description
State v. Mickey, 347 NC 508 (303A95)
State v. Richmond, 347 NC 412 (347A95)
State v. Smith, 347 NC 453 (233A96)
State v. Chance, 347 NC 566 (247PA96)
Creech v. Melnik, 347 NC 520 (539A96)
Stone v. N.C. Dept. of Labor, 347 NC 473 (81PA97)
McMillian v. N.C. Farm Bureau Mut. Ins. Co., 347 NC 560 (104PA97)
Cobo v. Raba, 347 NC 541 (127A97)
State v. T.D.R., 347 NC 489 (172PA97)
State v. Beatty, 347 NC 555 (255A97)
Johnson v. Southern Industrial Contractors, 347 NC 530 (282PA97)
Mullis v. Sechrest, 347 NC 548 (283A97)
VSA, Inc. v. Offerman, 347 NC 571 (319PA97)
Mellon v. Prosser, 347 NC 568 (361A97)
Barham v. Barham, 347 NC 570 (440A97)
Mitchell County DSS v. Carpenter, 347 NC 569 (450A97)
IN ADDITION TO THE ABOVE LISTED OPINIONS, THE COURT CONSIDERED OTHER MATTERS. THE OTHER MATTERS MAY INCLUDE, BUT ARE NOT LIMITED TO, NOTICES OF APPEALS BASED UPON CONSTITUTIONAL QUESTIONS, PETITIONS FOR DISCRETIONARY REVIEW, PETITIONS FOR WRIT OF CERTIORARI IN DEATH CASES, DEATH STAYS, PETITIONS FOR WRITS OF CERTIORARI IN OTHER CRIMINAL AND CIVIL CASES, PETITIONS FOR WRITS OF SUPERSEDEAS, MOTIONS FOR TEMPORARY STAYS, PETITIONS FOR WRITS OF MANDAMUS, PETITIONS FOR WRITS OF HABEAS CORPUS, PETITIONS FOR WRIT OF MANDAMUS, MOTIONS FOR APPROPRIATE RELIEF, AND DIRECT APPEALS FROM DECISIONS OF THE JUDICIAL STANDARDS COMMISSION AND THE UTILITIES COMMISSION. THE COURT ALSO CONSIDERS MOTIONS FOR EXTENSIONS OF TIME AND MOTIONS TO AMEND ON A DAILY BASIS. SUCH "ROUTINE" MOTIONS ARE NOT INCLUDED IN THE PETITION LIST PUBLISHED BY THE COURT EACH MONTH.